﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Text;

namespace EntityClassLibrary
{
    public partial class AdventureWorksEntities
    {
        public System.Collections.Generic.List<Product> GetProducts(object[] ids)
        {
            var intIDs = from id in ids select Convert.ToInt32(id);
            return Products.Where(
    BuildContainsExpression<Product, int>(e => e.ProductID, intIDs)).ToList();

        }

        public System.Collections.Generic.List<Product> GetAllProducts()
        {
            return Products.ToList();

        }

        static Expression<Func<TElement, bool>> BuildContainsExpression<TElement, TValue>(
    Expression<Func<TElement, TValue>> valueSelector, IEnumerable<TValue> values)
        {
            if (null == valueSelector) { throw new ArgumentNullException("valueSelector"); }
            if (null == values) { throw new ArgumentNullException("values"); }
            ParameterExpression p = valueSelector.Parameters.Single();
            // p => valueSelector(p) == values[0] || valueSelector(p) == ...
            if (!values.Any())
            {
                return e => false;
            }
            var equals = values.Select(value => (Expression)Expression.Equal(valueSelector.Body, Expression.Constant(value, typeof(TValue))));
            var body = equals.Aggregate<Expression>((accumulate, equal) => Expression.Or(accumulate, equal));
            return Expression.Lambda<Func<TElement, bool>>(body, p);
        }


    }
}
